Tenex.ParamPlug
(Tenex v1.0.8)
This is a basic plug that loads the current tenant assign from a given param.
To plug it on your router, you can use:
plug Tenex.ParamPlug,
param: :subdomain,
tenant_handler: &TenantHelper.tenant_handler/1See Tenex.ParamPlugConfig to check all the allowed config flags.